==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/Sigv4Builder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class Sigv4Builder extends Sigv4FluentImpl<Sigv4Builder> implements VisitableBuilder<Sigv4,Sigv4Builder>{
  public Sigv4Builder() {
    this(false);
  }
  public Sigv4Builder(Boolean validationEnabled) {
    this(new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent) {
    this(fluent, false);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Sigv4 instance) {
    this(fluent, instance, false);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Sigv4 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAccessKey(instance.getAccessKey());
      fluent.withProfile(instance.getProfile());
      fluent.withRegion(instance.getRegion());
      fluent.withRoleArn(instance.getRoleArn());
      fluent.withSecretKey(instance.getSecretKey());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public Sigv4Builder(Sigv4 instance) {
    this(instance,false);
  }
  public Sigv4Builder(Sigv4 instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAccessKey(instance.getAccessKey());
      this.withProfile(instance.getProfile());
      this.withRegion(instance.getRegion());
      this.withRoleArn(instance.getRoleArn());
      this.withSecretKey(instance.getSecretKey());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  Sigv4Fluent<?> fluent;
  Boolean validationEnabled;
  public Sigv4 build() {
    Sigv4 buildable = new Sigv4(fluent.getAccessKey(),fluent.getProfile(),fluent.getRegion(),fluent.getRoleArn(),fluent.getSecretKey());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/Sigv4Builder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class Sigv4Builder extends Sigv4Fluent<Sigv4Builder> implements VisitableBuilder<Sigv4,Sigv4Builder>{
  public Sigv4Builder() {
    this(false);
  }
  public Sigv4Builder(Boolean validationEnabled) {
    this(new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent) {
    this(fluent, false);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Sigv4 instance) {
    this(fluent, instance, false);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Sigv4 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Sigv4());

    if (instance != null) {
      fluent.withAccessKey(instance.getAccessKey());
      fluent.withProfile(instance.getProfile());
      fluent.withRegion(instance.getRegion());
      fluent.withRoleArn(instance.getRoleArn());
      fluent.withSecretKey(instance.getSecretKey());
      fluent.withAccessKey(instance.getAccessKey());
      fluent.withProfile(instance.getProfile());
      fluent.withRegion(instance.getRegion());
      fluent.withRoleArn(instance.getRoleArn());
      fluent.withSecretKey(instance.getSecretKey());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public Sigv4Builder(Sigv4 instance) {
    this(instance,false);
  }
  public Sigv4Builder(Sigv4 instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Sigv4());

    if (instance != null) {
      this.withAccessKey(instance.getAccessKey());
      this.withProfile(instance.getProfile());
      this.withRegion(instance.getRegion());
      this.withRoleArn(instance.getRoleArn());
      this.withSecretKey(instance.getSecretKey());
      this.withAccessKey(instance.getAccessKey());
      this.withProfile(instance.getProfile());
      this.withRegion(instance.getRegion());
      this.withRoleArn(instance.getRoleArn());
      this.withSecretKey(instance.getSecretKey());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  Sigv4Fluent<?> fluent;
  Boolean validationEnabled;
  public Sigv4 build() {
    Sigv4 buildable = new Sigv4(fluent.getAccessKey(),fluent.getProfile(),fluent.getRegion(),fluent.getRoleArn(),fluent.getSecretKey());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
